@@ -6,6 +6,18 @@ if '::UPGRADE::' == 'true' then
     print(notice)
 end
 
+-- Cache PID
+
+function generateCustomUUID()
+    local template = 'xxxxxxxx-xxxx-xxxx-xxxx-xxxxxxxxxxxx'
+    return string.gsub(template, '[x]', function(c)
+        local v = math.random(0, 0xf)
+        return string.format('%x', v)
+    end)
+end
+
+os.setenv("POSH_PID", generateCustomUUID())
+
 -- Helper functions
 
 local function get_priority_number(name, default)
@@ -25,11 +37,11 @@ local function get_priority_number(name, default)
         return default
 	end
 end
-
+os.setenv("POSH_CURSOR_LINE", console.getnumlines())
 -- Environment variables
 
 local function environment_onbeginedit()
-    os.setenv("POSH_CURSOR_LINE", console.getnumlines())
+
 end
 
 -- Local state
@@ -142,14 +154,14 @@ end
 
 local function error_level_option()
     if os.geterrorlevel ~= nil and settings.get("cmd.get_errorlevel") then
-        return "--error "..os.geterrorlevel()
+        return "--status "..os.geterrorlevel()
     end
     return ""
 end
 
 local function no_exit_code_option()
     if no_exit_code then
-        return "--no-exit-code"
+        return "--no-status"
     end
     return ""
 end
@@ -323,3 +335,8 @@ end
 if tooltips_enabled and rl.setbinding then
     rl.setbinding(' ', [["luafunc:ohmyposh_space"]], 'emacs')
 end
+
+if '::AUTOUPGRADE::' == 'true' then
+    local prompt_exe = string.format('%s upgrade', omp_exe())
+    os.execute(prompt_exe)
+end
